Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TaskPool ¶
type TaskPool struct {
// contains filtered or unexported fields
}
TaskPool manages concurrent processes. No more than size tasks run at once, and when a task returns an error, the Pool's context is cancelled.
Click to show internal directories.
Click to hide internal directories.